==> piwigo-11.5.0.zip: piwigo/language/cs_CZ/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Instalace';
$lang['Basic configuration'] = 'Základní konfigurace';
$lang['Default gallery language'] = 'Základní jazyk galerie';
$lang['Database configuration'] = 'Databázová konfigurace';
$lang['Admin configuration'] = 'Administrátorská konfigurace';
$lang['Start Install'] = 'Spustit instalaci';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Bude zobrazen návštěvníkům. Je nutný pro administraci aplikace.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Spojení na server se podařilo, ale nebylo možné připojit databázi';
$lang['Can\'t connect to server'] = 'Nebylo možné se připojit k serveru';
$lang['Host'] = 'MySQL server';
$lang['User'] = 'Uživatel';
$lang['user login given by your host provider'] = 'uživatelské jméno, které Vám přidělil provozovatel serveru';
$lang['user password given by your host provider'] = 'heslo na tomto serveru';
$lang['Database name'] = 'Jméno databáze';
$lang['also given by your host provider'] = 'které na tomto serveru';
$lang['Database table prefix'] = 'Předpona názvů databázových tabulek';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'názvy vytvořených databázových tabulek budou tuto předponu (pro jejich snadnější správu)';
$lang['enter a login for webmaster'] = 'vložte uživatelské jméno správce';
$lang['webmaster login can\'t contain characters \' or "'] = 'uživatelské jméno správce nemůže obsahovat znak \' nebo "';
$lang['please enter your password again'] = 'prosím zadejte znovu heslo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Heslo mějte utajeno, umožní Vám přístup do administrace aplikace';
$lang['Password [confirm]'] = 'Heslo [potvrzení]';
$lang['verification'] = 'kontrola';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Potřebujete pomoc ? Zeptejte se na <a href="%s">Piwigo fóru</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Návštěvníci mohou pomocí tohoto e-mailu správce kontaktovat';
$lang['PHP 5 is required'] = 'Je nutný PHP 5.2';
$lang['It appears your webhost is currently running PHP %s.'] = 'Na Vašem webhostingu je PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo se může pokusit změnit Vaše nastavení na PHP 5.2 tím, že vytvoří nebo změní soubor .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Případně můžete změnit Vaši konfirguraci sami a potom restartovat Piwigo .';
$lang['Try to configure PHP 5'] = 'Pokuste se změnit Vaše nastavení na PHP 5.2';
$lang['Sorry!'] = 'Bohužel!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo nebylo schopno změnit Vaše nastavení na PHP 5.2';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Obraťte se na poskytovatele Vašeho webhostingu, aby jste zjistili, jak můžete změnit Vaše nastavení na PHP 5.2';
$lang['Hope to see you back soon.'] = 'Věříme, že se brzy uvidíme.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulujeme, Piwigo instalace je ukončena';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Náhradním řešením je zkopírovat text z boxu výše a vložit jej do souboru "local/config/database.inc.php" (Upozornění : soubor database.inc.php smí obsahovat jen to, co je v tomto boxu, žádné znaky odřádkování nebo mezery)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Vytvoření souboru local/config/database.inc.php se nepodařilo.';
$lang['Download the config file'] = 'Stáhnout konfigurační soubor';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Můžete stáhnout konfigurační soubor a nahrát jej do adrešáře local/config Vaší instalace.';
$lang['Just another Piwigo gallery'] = 'Jen další galerie Piwigo';
$lang['Welcome to my photo gallery'] = 'Vítejte na mé fotogalerii';
$lang['Welcome to your new installation of Piwigo!'] = 'Vítejte v nové instalaci Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Neváhejte navštívit naše fórum v případě jakýchkoliv dotazů: %s'; 
$lang['localhost or other, supplied by your host provider'] = 'localhost, nebo jiný, dodaný poskytovatelem hostingu';

==> piwigo-16.3.0.zip: piwigo/language/cs_CZ/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Instalace';
$lang['Basic configuration'] = 'Základní konfigurace';
$lang['Default gallery language'] = 'Základní jazyk galerie';
$lang['Database configuration'] = 'Databázová konfigurace';
$lang['Admin configuration'] = 'Administrátorská konfigurace';
$lang['Start Install'] = 'Spustit instalaci';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Bude zobrazen návštěvníkům. Je nutný pro administraci aplikace.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Spojení na server se podařilo, ale nebylo možné připojit databázi';
$lang['Can\'t connect to server'] = 'Nebylo možné se připojit k serveru';
$lang['Host'] = 'MySQL server';
$lang['User'] = 'Uživatel';
$lang['user login given by your host provider'] = 'uživatelské jméno, které Vám přidělil provozovatel serveru';
$lang['user password given by your host provider'] = 'heslo na tomto serveru';
$lang['Database name'] = 'Jméno databáze';
$lang['also given by your host provider'] = 'které na tomto serveru';
$lang['Database table prefix'] = 'Předpona názvů databázových tabulek';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'názvy vytvořených databázových tabulek budou tuto předponu (pro jejich snadnější správu)';
$lang['enter a login for webmaster'] = 'vložte uživatelské jméno správce';
$lang['webmaster login can\'t contain characters \' or "'] = 'uživatelské jméno správce nemůže obsahovat znak \' nebo "';
$lang['please enter your password again'] = 'prosím zadejte znovu heslo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Heslo mějte utajeno, umožní Vám přístup do administrace aplikace';
$lang['Password [confirm]'] = 'Heslo [potvrzení]';
$lang['verification'] = 'kontrola';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Potřebujete pomoc ? Zeptejte se na <a href="%s">Piwigo fóru</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Návštěvníci mohou pomocí tohoto e-mailu správce kontaktovat';
$lang['PHP 5 is required'] = 'Je nutný PHP 5.2';
$lang['It appears your webhost is currently running PHP %s.'] = 'Na Vašem webhostingu je PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo se může pokusit změnit Vaše nastavení na PHP 5.2 tím, že vytvoří nebo změní soubor .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Případně můžete změnit Vaši konfirguraci sami a potom restartovat Piwigo .';
$lang['Try to configure PHP 5'] = 'Pokuste se změnit Vaše nastavení na PHP 5.2';
$lang['Sorry!'] = 'Bohužel!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo nebylo schopno změnit Vaše nastavení na PHP 5.2';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Obraťte se na poskytovatele Vašeho webhostingu, aby jste zjistili, jak můžete změnit Vaše nastavení na PHP 5.2';
$lang['Hope to see you back soon.'] = 'Věříme, že se brzy uvidíme.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulujeme, Piwigo instalace je ukončena';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Náhradním řešením je zkopírovat text z boxu výše a vložit jej do souboru "local/config/database.inc.php" (Upozornění : soubor database.inc.php smí obsahovat jen to, co je v tomto boxu, žádné znaky odřádkování nebo mezery)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Vytvoření souboru local/config/database.inc.php se nepodařilo.';
$lang['Download the config file'] = 'Stáhnout konfigurační soubor';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Můžete stáhnout konfigurační soubor a nahrát jej do adrešáře local/config Vaší instalace.';
$lang['Just another Piwigo gallery'] = 'Jen další galerie Piwigo';
$lang['Welcome to my photo gallery'] = 'Vítejte na mé fotogalerii';
$lang['Welcome to your new installation of Piwigo!'] = 'Vítejte v nové instalaci Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Neváhejte navštívit naše fórum v případě jakýchkoliv dotazů: %s'; 
$lang['localhost or other, supplied by your host provider'] = 'localhost, nebo jiný, dodaný poskytovatelem hostingu';
$lang['PHP version %s required (you are running on PHP %s)'] = 'Je vyžadováno PHP verze %s (nyní používáte PHP %s)';
